==> Products.Reportek-4.0.6.zip: Products.Reportek-4.0.6/Products/Reportek/tests/testFGASRegistryApi.py <==
# -*- coding: utf-8 -*-

import json

from mock import Mock, patch
from Products.Reportek.RegistryManagement import FGASRegistryAPI
from Products.Reportek.Collection import Collection
from common import BaseTest, ConfigureReportek


class FGASRegistryAPITest(BaseTest, ConfigureReportek):
    userDetailInput = u"""
    [{"company_id": 1234,
      "name": "Blă Brul",
      "country": "RO",
      "domain": "FGAS",
      "collection_id": "fgas30001",
      "country_history": [
        "UK"
        ]
      },
     {"company_id": 12345,
      "name": "Blâ Brul",
      "country": "RO",
      "domain": "FGAS",
      "collection_id": null}
    ]
    """
    def afterSetUp(self):
        super(FGASRegistryAPITest, self).afterSetUp()
        api = FGASRegistryAPI('FGASRegistryAPI', 'http://localhost:5000')
        self.root._setObject('api', api)
        # create the previous collection
        fgases = Collection(id='fgases')
        gb = Collection(id='gb')
        fgases._setObject(gb.id, gb)
        fgas30001 = Collection(id='fgas30001')
        gb._setObject(fgas30001.id, fgas30001)
        self.root._setObject(fgases.id, fgases)

    @patch('requests.get')
    def test_getCollectionPaths(self, req_mock):
        rsp = Mock()
        req_mock.return_value = rsp
        rsp.status_code = 200
        rsp.text = self.userDetailInput
        rsp.json = Mock(return_value=json.loads(rsp.text))

        username = 'vasile'
        expectedPaths = {
            'paths': [u'fgases/ro/fgas30001', u'fgases/ro/12345'],
            'prev_paths': ['fgases/gb/fgas30001']
        }

        paths = self.root.api.getCollectionPaths(username)
        self.assertEqual(req_mock.call_args[0][0], self.root.api.baseUrl + '/user/' + username + '/companies')
        self.assertEqual(paths, expectedPaths)

==> Products.Reportek-4.20.zip: Products.Reportek-4.20/Products/Reportek/tests/testFGASRegistryApi.py <==
# -*- coding: utf-8 -*-

import json

from mock import Mock, patch
from Products.Reportek.RegistryManagement import FGASRegistryAPI
from Products.Reportek.Collection import Collection
from common import BaseTest


class FGASRegistryAPITest(BaseTest):
    userDetailInput = u"""
    [{"company_id": 1234,
      "name": "Blă Brul",
      "country": "RO",
      "domain": "FGAS",
      "collection_id": "fgas30001",
      "country_history": [
        "UK"
        ]
      },
     {"company_id": 12345,
      "name": "Blâ Brul",
      "country": "RO",
      "domain": "FGAS",
      "collection_id": null}
    ]
    """

    def afterSetUp(self):
        super(FGASRegistryAPITest, self).afterSetUp()
        api = FGASRegistryAPI('FGASRegistryAPI', 'http://localhost:5000')
        self.root._setObject('api', api)
        # create the previous collection
        fgases = Collection(id='fgases')
        gb = Collection(id='gb')
        fgases._setObject(gb.id, gb)
        fgas30001 = Collection(id='fgas30001')
        gb._setObject(fgas30001.id, fgas30001)
        self.root._setObject(fgases.id, fgases)

    @patch('requests.get')
    def test_getCollectionPaths(self, req_mock):
        rsp = Mock()
        req_mock.return_value = rsp
        rsp.status_code = 200
        rsp.text = self.userDetailInput
        rsp.json = Mock(return_value=json.loads(rsp.text))

        username = 'vasile'
        expectedPaths = {
            'paths': ['fgases/ro/fgas30001', 'fgases/ro/12345'],
            'prev_paths': ['fgases/gb/fgas30001']
        }

        paths = self.root.api.getCollectionPaths(username)

        self.assertEqual(
            req_mock.call_args[0][0],
            self.root.api.baseUrl + '/user/' + username + '/companies')
        self.assertEqual(paths, expectedPaths)
